"""
Structured information on a bundle of file instances.
"""

# this file was auto-generated

from datetime import date, datetime
from fairgraph import KGObject, IRI
from fairgraph.fields import Field


class FileBundle(KGObject):
    """
    Structured information on a bundle of file instances.
    """

    default_space = "files"
    type_ = ["https://openminds.ebrains.eu/core/FileBundle"]
    context = {
        "schema": "http://schema.org/",
        "kg": "https://kg.ebrains.eu/api/instances/",
        "vocab": "https://openminds.ebrains.eu/vocab/",
        "terms": "https://openminds.ebrains.eu/controlledTerms/",
        "core": "https://openminds.ebrains.eu/core/",
    }
    fields = [
        Field(
            "name",
            str,
            "vocab:name",
            required=True,
            doc="Word or phrase that constitutes the distinctive designation of the file bundle.",
        ),
        Field("content_description", str, "vocab:contentDescription", doc="no description available"),
        Field(
            "format",
            "openminds.core.ContentType",
            "vocab:format",
            doc="Method of digitally organizing and structuring data or information.",
        ),
        Field(
            "grouped_by",
            [
                "openminds.computation.LocalFile",
                "openminds.controlledterms.AnalysisTechnique",
                "openminds.controlledterms.AuditoryStimulusType",
                "openminds.controlledterms.BiologicalOrder",
                "openminds.controlledterms.BiologicalSex",
                "openminds.controlledterms.BreedingType",
                "openminds.controlledterms.CellCultureType",
                "openminds.controlledterms.CellType",
                "openminds.controlledterms.Disease",
                "openminds.controlledterms.DiseaseModel",
                "openminds.controlledterms.ElectricalStimulusType",
                "openminds.controlledterms.GeneticStrainType",
                "openminds.controlledterms.GustatoryStimulusType",
                "openminds.controlledterms.Handedness",
                "openminds.controlledterms.MolecularEntity",
                "openminds.controlledterms.OlfactoryStimulusType",
                "openminds.controlledterms.OpticalStimulusType",
                "openminds.controlledterms.Organ",
                "openminds.controlledterms.OrganismSubstance",
                "openminds.controlledterms.OrganismSystem",
                "openminds.controlledterms.Species",
                "openminds.controlledterms.StimulationApproach",
                "openminds.controlledterms.StimulationTechnique",
                "openminds.controlledterms.SubcellularEntity",
                "openminds.controlledterms.TactileStimulusType",
                "openminds.controlledterms.Technique",
                "openminds.controlledterms.TermSuggestion",
                "openminds.controlledterms.UBERONParcellation",
                "openminds.controlledterms.VisualStimulusType",
                "openminds.core.BehavioralProtocol",
                "openminds.core.File",
                "openminds.core.FileBundle",
                "openminds.core.Subject",
                "openminds.core.SubjectGroup",
                "openminds.core.SubjectGroupState",
                "openminds.core.SubjectState",
                "openminds.core.TissueSample",
                "openminds.core.TissueSampleCollection",
                "openminds.core.TissueSampleCollectionState",
                "openminds.core.TissueSampleState",
                "openminds.sands.CommonCoordinateSpace",
                "openminds.sands.CommonCoordinateSpaceVersion",
                "openminds.sands.CustomAnatomicalEntity",
                "openminds.sands.CustomCoordinateSpace",
                "openminds.sands.ParcellationEntity",
                "openminds.sands.ParcellationEntityVersion",
            ],
            "vocab:groupedBy",
            multiple=True,
            doc="Reference to the aspect used to group something.",
        ),
        Field(
            "grouping_types",
            "openminds.controlledterms.FileBundleGrouping",
            "vocab:groupingType",
            multiple=True,
            doc="no description available",
        ),
        Field(
            "hash",
            "openminds.core.Hash",
            "vocab:hash",
            doc="Term used for the process of converting any data into a single value. Often also directly refers to the resulting single value.",
        ),
        Field(
            "is_part_of",
            ["openminds.core.FileBundle", "openminds.core.FileRepository"],
            "vocab:isPartOf",
            required=True,
            doc="Reference to the ensemble of multiple things or beings.",
        ),
        Field(
            "storage_size",
            "openminds.core.QuantitativeValue",
            "vocab:storageSize",
            doc="Quantitative value defining how much disk space is used by an object on a computer system.",
        ),
        Field(
            "describes",
            [
                "openminds.ephys.ElectrodeArrayUsage",
                "openminds.ephys.ElectrodeUsage",
                "openminds.ephys.PipetteUsage",
                "openminds.specimenprep.SlicingDeviceUsage",
            ],
            "^vocab:metadataLocation",
            reverse="metadata_locations",
            multiple=True,
            doc="reverse of 'metadataLocation'",
        ),
        Field(
            "has_parts",
            ["openminds.core.File", "openminds.core.FileBundle"],
            "^vocab:isPartOf",
            reverse="is_part_of",
            multiple=True,
            doc="reverse of 'isPartOf'",
        ),
        Field(
            "is_also_part_of",
            "openminds.computation.WorkflowRecipeVersion",
            "^vocab:hasPart",
            reverse="has_parts",
            multiple=True,
            doc="reverse of 'hasPart'",
        ),
        Field(
            "is_input_to",
            "openminds.core.DatasetVersion",
            "^vocab:inputData",
            reverse="input_data",
            multiple=True,
            doc="reverse of 'inputData'",
        ),
        Field(
            "is_location_of",
            ["openminds.core.ServiceLink", "openminds.ephys.Recording"],
            "^vocab:dataLocation",
            reverse="data_locations",
            multiple=True,
            doc="reverse of 'dataLocation'",
        ),
        Field(
            "is_output_of",
            [
                "openminds.computation.DataAnalysis",
                "openminds.computation.DataCopy",
                "openminds.computation.GenericComputation",
                "openminds.computation.ModelValidation",
                "openminds.computation.Optimization",
                "openminds.computation.Simulation",
                "openminds.computation.Visualization",
                "openminds.core.ModelVersion",
                "openminds.core.ProtocolExecution",
                "openminds.ephys.RecordingActivity",
            ],
            ["^vocab:output", "^vocab:outputData"],
            reverse=["outputs", "output_data"],
            multiple=True,
            doc="reverse of output, outputData",
        ),
        Field(
            "is_reference_for",
            "openminds.computation.ValidationTestVersion",
            "^vocab:referenceData",
            reverse="reference_data",
            multiple=True,
            doc="reverse of 'referenceData'",
        ),
    ]
    existence_query_fields = ("name", "is_part_of")

    def __init__(
        self,
        name=None,
        content_description=None,
        format=None,
        grouped_by=None,
        grouping_types=None,
        hash=None,
        is_part_of=None,
        storage_size=None,
        describes=None,
        has_parts=None,
        is_also_part_of=None,
        is_input_to=None,
        is_location_of=None,
        is_output_of=None,
        is_reference_for=None,
        id=None,
        data=None,
        space=None,
        scope=None,
    ):
        return super().__init__(
            id=id,
            space=space,
            scope=scope,
            data=data,
            name=name,
            content_description=content_description,
            format=format,
            grouped_by=grouped_by,
            grouping_types=grouping_types,
            hash=hash,
            is_part_of=is_part_of,
            storage_size=storage_size,
            describes=describes,
            has_parts=has_parts,
            is_also_part_of=is_also_part_of,
            is_input_to=is_input_to,
            is_location_of=is_location_of,
            is_output_of=is_output_of,
            is_reference_for=is_reference_for,
        )
